Re: [E-devel] [EGIT] [core/enlightenment] master 01/01: wl_drm: Fix creation of the ecore_evas_gl_drm

2015-01-16 Thread Stefan Schmidt
Hello.

On 15/01/15 19:30, Christopher Michael wrote:
> devilhorns pushed a commit to branch master.
>
> http://git.enlightenment.org/core/enlightenment.git/commit/?id=63dc694f56e8eae061cc7bbfde4b91e6fa48bd29
>
> commit 63dc694f56e8eae061cc7bbfde4b91e6fa48bd29
> Author: Chris Michael 
> Date:   Thu Jan 15 13:29:43 2015 -0500
>
> wl_drm: Fix creation of the ecore_evas_gl_drm
> 
> Signed-off-by: Chris Michael 
> ---
>  src/modules/wl_drm/e_mod_main.c | 4 ++--
>  1 file changed, 2 insertions(+), 2 deletions(-)
>
> diff --git a/src/modules/wl_drm/e_mod_main.c b/src/modules/wl_drm/e_mod_main.c
> index 118f9ef..795c415 100644
> --- a/src/modules/wl_drm/e_mod_main.c
> +++ b/src/modules/wl_drm/e_mod_main.c
> @@ -76,8 +76,8 @@ e_modapi_init(E_Module *m)
> if ((e_comp_gl_get()) &&
> (e_comp_config_get()->engine == E_COMP_ENGINE_GL))
>   {
> -comp->ee == ecore_evas_gl_drm_new(NULL, 0, 0, 0, 1, 1);
> -if(!comp->ee)
> +comp->ee = ecore_evas_gl_drm_new(NULL, 0, 0, 0, 1, 1);
> +if (!comp->ee)
>e_comp_gl_set(EINA_FALSE);
>   }
>  

If we get a patch in phab which has only two lines of changes and both
of them have to be fixed afterwards I would suggest that we don't submit
this one as is and do a fix commit afterwards.

The idea to review patches from people is that we provide feedback
before the code enters our repo and the contributor can learn and
hopefully improve his patches.

regards
Stefan Schmidt

--
New Year. New Location. New Benefits. New Data Center in Ashburn, VA.
GigeNET is offering a free month of service with a new server in Ashburn.
Choose from 2 high performing configs, both with 100TB of bandwidth.
Higher redundancy.Lower latency.Increased capacity.Completely compliant.
http://p.sf.net/sfu/gigenet
___
enlightenment-devel mailing list
enlightenment-devel@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/enlightenment-devel


[EGIT] [core/enlightenment] master 01/01: comp base - make base black. makes for better screenshots of blank areas

2015-01-16 Thread Carsten Haitzler
raster pushed a commit to branch master.

http://git.enlightenment.org/core/enlightenment.git/commit/?id=fe892a3ce068b3800634c79a2f655049842dd05c

commit fe892a3ce068b3800634c79a2f655049842dd05c
Author: Carsten Haitzler (Rasterman) 
Date:   Fri Jan 16 17:50:34 2015 +0900

comp base - make base black. makes for better screenshots of blank areas
---
 src/bin/e_comp_canvas.c | 2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)

diff --git a/src/bin/e_comp_canvas.c b/src/bin/e_comp_canvas.c
index 61e82bf..5425ddc 100644
--- a/src/bin/e_comp_canvas.c
+++ b/src/bin/e_comp_canvas.c
@@ -140,7 +140,7 @@ e_comp_canvas_init(E_Comp *c)
evas_object_layer_set(o, E_LAYER_BOTTOM);
evas_object_move(o, 0, 0);
evas_object_resize(o, c->man->w, c->man->h);
-   evas_object_color_set(o, 255, 255, 255, 255);
+   evas_object_color_set(o, 0, 0, 0, 255);
evas_object_name_set(o, "comp->bg_blank_object");
evas_object_data_set(o, "e_comp", c);
evas_object_event_callback_add(o, EVAS_CALLBACK_MOUSE_DOWN, 
(Evas_Object_Event_Cb)_e_comp_canvas_cb_mouse_down, c);

-- 




[EGIT] [tools/enventor] master 01/01: edc_parser: Fix to show double quotation marks(")

2015-01-16 Thread Jaehyun Cho
jaehyun pushed a commit to branch master.

http://git.enlightenment.org/tools/enventor.git/commit/?id=af1dc2f23d5ac3dd55b1f81ef7dfcf4aa19413f4

commit af1dc2f23d5ac3dd55b1f81ef7dfcf4aa19413f4
Author: Jaehyun Cho 
Date:   Fri Jan 16 17:56:26 2015 +0900

edc_parser: Fix to show double quotation marks(")

Change the markup for double quotation marks from "\"" to """.
---
 src/lib/edc_parser.c   | 12 +++-
 src/lib/enventor_private.h |  5 ++---
 src/lib/syntax_color.c | 21 -
 3 files changed, 17 insertions(+), 21 deletions(-)

diff --git a/src/lib/edc_parser.c b/src/lib/edc_parser.c
index 71c12aa..549393a 100644
--- a/src/lib/edc_parser.c
+++ b/src/lib/edc_parser.c
@@ -68,7 +68,7 @@ group_name_thread_blocking(void *data, Ecore_Thread *thread 
EINA_UNUSED)
while (p <= end)
  {
 //Skip "" range
-if (*p == *quot)
+if (!strncmp(p, quot, quot_len))
   {
  p += quot_len;
  p = strstr(p, quot);
@@ -146,7 +146,7 @@ cur_name_thread_blocking(void *data, Ecore_Thread *thread 
EINA_UNUSED)
while (p <= end)
  {
 //Skip "" range
-if (*p == *quot)
+if (!strncmp(p, quot, quot_len))
   {
  p += quot_len;
  p = strstr(p, quot);
@@ -851,6 +851,7 @@ group_beginning_pos_get(const char* source, const char 
*group_name)
 {
const char* GROUP_SYNTAX_NAME = "group";
const char *quot = QUOT;
+   const int quot_len = QUOT_LEN;
 
const char *pos = strstr(source, GROUP_SYNTAX_NAME);
 
@@ -859,7 +860,8 @@ group_beginning_pos_get(const char* source, const char 
*group_name)
{
   const char *name = strstr(pos, quot);
   if (!name) return NULL;
-  pos = strstr(++name, quot);
+  name += quot_len;
+  pos = strstr(name, quot);
   if (!pos) return NULL;
   if (!strncmp(name, group_name, strlen(group_name)))
 return pos;
@@ -1054,7 +1056,7 @@ parser_paragh_name_get(parser_data *pd EINA_UNUSED, 
Evas_Object *entry)
while (cur <= end)
  {
 //Skip "" range
-if (*cur == *quot)
+if (!strncmp(cur, quot, quot_len))
   {
  cur += quot_len;
  cur = strstr(cur, quot);
@@ -1118,7 +1120,7 @@ parser_cur_name_fast_get(Evas_Object *entry, const char 
*scope)
while (p <= end)
  {
 //Skip "" range
-if (*p == *quot)
+if (!strncmp(p, quot, quot_len))
   {
  p += quot_len;
  p = strstr(p, quot);
diff --git a/src/lib/enventor_private.h b/src/lib/enventor_private.h
index d89e04f..925a88f 100644
--- a/src/lib/enventor_private.h
+++ b/src/lib/enventor_private.h
@@ -1,9 +1,8 @@
 #ifndef __ENVENTOR_PRIVATE_H__
 #define __ENVENTOR_PRIVATE_H__
 
-#define QUOT "\""
-#define QUOT_C '\"'
-#define QUOT_LEN 1
+#define QUOT """
+#define QUOT_LEN 6
 #define EOL ""
 #define EOL_LEN 5
 #define TAB ""
diff --git a/src/lib/syntax_color.c b/src/lib/syntax_color.c
index 95b5602..6040f97 100644
--- a/src/lib/syntax_color.c
+++ b/src/lib/syntax_color.c
@@ -386,25 +386,20 @@ string_apply(Eina_Strbuf *strbuf, char **cur, char **prev,
  const Eina_Stringshare *col, Eina_Bool inside_string)
 {
//escape string: " ~ "
-   if ((*cur)[0] != QUOT_C) return 0;
+   if (strncmp(*cur, QUOT, QUOT_LEN)) return 0;
 
char buf[128];
 
-   if (!inside_string)
- {
-snprintf(buf, sizeof(buf), "", col);
-eina_strbuf_append(strbuf, buf);
- }
-
eina_strbuf_append_length(strbuf, *prev, (*cur - *prev) + 1);
 
-   if (inside_string)
- {
-snprintf(buf, sizeof(buf), "");
-eina_strbuf_append(strbuf, buf);
- }
+   if (!inside_string)
+ snprintf(buf, sizeof(buf), "%s", col, QUOT);
+   else
+ snprintf(buf, sizeof(buf), "%s", QUOT);
 
-   (*cur)++;
+   eina_strbuf_append(strbuf, buf);
+
+   *cur += QUOT_LEN;
*prev = *cur;
 
return 1;

-- 




Re: [E-devel] [EGIT] [core/enlightenment] master 01/01: wl_drm: Fix creation of the ecore_evas_gl_drm

2015-01-16 Thread Kabeer Ahmed Khan

   Hi Stefan


   Sorry man this was my mistake. It was most silly one and I will make sure
   this never happens in future.

   Thanks for pointing that out.


   cheers

   Kabeer


   --- Original Message ---

   Sender : Stefan Schmidt

   Date : Jan 16, 2015 14:04 (GMT+05:30)

   Title : Re: [E-devel] [EGIT] [core/enlightenment] master 01/01: wl_drm: Fix
   creation of the ecore_evas_gl_drm


   Hello.
   On 15/01/15 19:30, Christopher Michael wrote:
   > devilhorns pushed a commit to branch master.
   >
   >
   http://git.enlightenment.org/core/enlightenment.git/commit/?id=63dc694f56e8e
   ae061cc7bbfde4b91e6fa48bd29
   >
   > commit 63dc694f56e8eae061cc7bbfde4b91e6fa48bd29
   > Author: Chris Michael
   > Date:   Thu Jan 15 13:29:43 2015 -0500
   >
   > wl_drm: Fix creation of the ecore_evas_gl_drm
   >
   > Signed-off-by: Chris Michael
   > ---
   >  src/modules/wl_drm/e_mod_main.c | 4 ++--
   >  1 file changed, 2 insertions(+), 2 deletions(-)
   >
   > diff --git a/src/modules/wl_drm/e_mod_main.c
   b/src/modules/wl_drm/e_mod_main.c
   > index 118f9ef..795c415 100644
   > --- a/src/modules/wl_drm/e_mod_main.c
   > +++ b/src/modules/wl_drm/e_mod_main.c
   > @@ -76,8 +76,8 @@ e_modapi_init(E_Module *m)
   > if ((e_comp_gl_get()) &&
   > (e_comp_config_get()->engine == E_COMP_ENGINE_GL))
   >   {
   > -comp->ee == ecore_evas_gl_drm_new(NULL, 0, 0, 0, 1, 1);
   > -if(!comp->ee)
   > +comp->ee = ecore_evas_gl_drm_new(NULL, 0, 0, 0, 1, 1);
   > +if (!comp->ee)
   >e_comp_gl_set(EINA_FALSE);
   >   }
   >
   If we get a patch in phab which has only two lines of changes and both
   of them have to be fixed afterwards I would suggest that we don't submit
   this one as is and do a fix commit afterwards.
   The idea to review patches from people is that we provide feedback
   before the code enters our repo and the contributor can learn and
   hopefully improve his patches.
   regards
   Stefan Schmidt
   
   --
   New Year. New Location. New Benefits. New Data Center in Ashburn, VA.
   GigeNET is offering a free month of service with a new server in Ashburn.
   Choose from 2 high performing configs, both with 100TB of bandwidth.
   Higher redundancy.Lower latency.Increased capacity.Completely compliant.
   http://p.sf.net/sfu/gigenet
   ___
   enlightenment-devel mailing list
   enlightenment-devel@lists.sourceforge.net
   https://lists.sourceforge.net/lists/listinfo/enlightenment-devel



   [cid:BGFC2LL5XOK0@namo.co.kr]

   [SeenTimeChecker?do=6db27cebcd8822fb24b6d4333447f6560d5fc3afaf7efa5d53e47e2f
   243a5ca9ddc79e3cd10304db25139e580ce36374e458eb91567068af8048f33cf1ed6b022630
   67d8b8f027b11b20909a04efd4d2748cfe1d4e847419cf878f9a26ce15a0]
--
New Year. New Location. New Benefits. New Data Center in Ashburn, VA.
GigeNET is offering a free month of service with a new server in Ashburn.
Choose from 2 high performing configs, both with 100TB of bandwidth.
Higher redundancy.Lower latency.Increased capacity.Completely compliant.
http://p.sf.net/sfu/gigenet___
enlightenment-devel mailing list
enlightenment-devel@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/enlightenment-devel


Re: [E-devel] [EGIT] [tools/edi] master 03/03: Don't try to open recent projects if they can't be found.

2015-01-16 Thread Stefan Schmidt
Hello.

On 16/01/15 00:13, Andy Williams wrote:
> ajwillia-ms pushed a commit to branch master.
>
> http://git.enlightenment.org/tools/edi.git/commit/?id=123c137a2412b2021bc4b0d5196eb457c799025b
>
> commit 123c137a2412b2021bc4b0d5196eb457c799025b
> Author: Andy Williams 
> Date:   Thu Jan 15 23:13:14 2015 +
>
> Don't try to open recent projects if they can't be found.
> 
> Allow the user to choose if it should be deleted or not before returning.
> Submitted by Kelly Wilson

How did he submit these patches? As git formatted ones? If yes I think
it would be nice to make sure you keep the authorship of these patches.

regards
Stefan Schmidt


--
New Year. New Location. New Benefits. New Data Center in Ashburn, VA.
GigeNET is offering a free month of service with a new server in Ashburn.
Choose from 2 high performing configs, both with 100TB of bandwidth.
Higher redundancy.Lower latency.Increased capacity.Completely compliant.
http://p.sf.net/sfu/gigenet
___
enlightenment-devel mailing list
enlightenment-devel@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/enlightenment-devel


[E-devel] Bug list for 1.13

2015-01-16 Thread Stefan Schmidt
Hello.

Its again this time of the release cycle: Bug fixing!

I have a query for all efl and elm bugs excluding whishlist items:
https://phab.enlightenment.org/maniphest/query/AVSkCM86TT.L/

Not sure if this is private to my account or if others can use it as well.

With three weeks ahead before the 1.13 release it would be good if we
get an idea how many showstopper and important bugs we have that would
need fixing before the release.

I cleared out the incoming queue and added the priority I saw fit.

What I see right now is one showstopper bug (T2002, genlust) and 11
important bugs classified as high.
Some of the bugs classified as high are over six month old so I would
think that they can't be that important really.

Please have a look at the list and adjust the priorities if you see fit,
but please avoid bumping the  bug that annoys you to showstopper. :)

Also please have a look at the bugs if you have the expertise in this
area to help to get them solved before the release.

regards
Stefan Schmidt


--
New Year. New Location. New Benefits. New Data Center in Ashburn, VA.
GigeNET is offering a free month of service with a new server in Ashburn.
Choose from 2 high performing configs, both with 100TB of bandwidth.
Higher redundancy.Lower latency.Increased capacity.Completely compliant.
http://p.sf.net/sfu/gigenet
___
enlightenment-devel mailing list
enlightenment-devel@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/enlightenment-devel


Re: [E-devel] Bug list for 1.13

2015-01-16 Thread Tom Hacohen
On 16/01/15 10:20, Stefan Schmidt wrote:
> Hello.
>
> Its again this time of the release cycle: Bug fixing!
>
> I have a query for all efl and elm bugs excluding whishlist items:
> https://phab.enlightenment.org/maniphest/query/AVSkCM86TT.L/
>
> Not sure if this is private to my account or if others can use it as well.
>
> With three weeks ahead before the 1.13 release it would be good if we
> get an idea how many showstopper and important bugs we have that would
> need fixing before the release.
>
> I cleared out the incoming queue and added the priority I saw fit.
>
> What I see right now is one showstopper bug (T2002, genlust) and 11
> important bugs classified as high.
> Some of the bugs classified as high are over six month old so I would
> think that they can't be that important really.
>
> Please have a look at the list and adjust the priorities if you see fit,
> but please avoid bumping the  bug that annoys you to showstopper. :)
>
> Also please have a look at the bugs if you have the expertise in this
> area to help to get them solved before the release.

Not private, I can see that just fine.

--
Tom.



--
New Year. New Location. New Benefits. New Data Center in Ashburn, VA.
GigeNET is offering a free month of service with a new server in Ashburn.
Choose from 2 high performing configs, both with 100TB of bandwidth.
Higher redundancy.Lower latency.Increased capacity.Completely compliant.
http://p.sf.net/sfu/gigenet
___
enlightenment-devel mailing list
enlightenment-devel@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/enlightenment-devel


Re: [E-devel] Bug list for 1.13

2015-01-16 Thread Stefan Schmidt
Hello.

On 16/01/15 12:05, Tom Hacohen wrote:
> On 16/01/15 10:20, Stefan Schmidt wrote:
>> Hello.
>>
>> Its again this time of the release cycle: Bug fixing!
>>
>> I have a query for all efl and elm bugs excluding whishlist items:
>> https://phab.enlightenment.org/maniphest/query/AVSkCM86TT.L/
>>
>> Not sure if this is private to my account or if others can use it as well.
>>
>> With three weeks ahead before the 1.13 release it would be good if we
>> get an idea how many showstopper and important bugs we have that would
>> need fixing before the release.
>>
>> I cleared out the incoming queue and added the priority I saw fit.
>>
>> What I see right now is one showstopper bug (T2002, genlust) and 11
>> important bugs classified as high.
>> Some of the bugs classified as high are over six month old so I would
>> think that they can't be that important really.
>>
>> Please have a look at the list and adjust the priorities if you see fit,
>> but please avoid bumping the  bug that annoys you to showstopper. :)
>>
>> Also please have a look at the bugs if you have the expertise in this
>> area to help to get them solved before the release.
> Not private, I can see that just fine.

Cool.

regards
Stefan Schmidt

--
New Year. New Location. New Benefits. New Data Center in Ashburn, VA.
GigeNET is offering a free month of service with a new server in Ashburn.
Choose from 2 high performing configs, both with 100TB of bandwidth.
Higher redundancy.Lower latency.Increased capacity.Completely compliant.
http://p.sf.net/sfu/gigenet
___
enlightenment-devel mailing list
enlightenment-devel@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/enlightenment-devel


[EGIT] [core/elementary] master 01/01: Updating italian translation

2015-01-16 Thread Massimo Maiurana
maxerba pushed a commit to branch master.

http://git.enlightenment.org/core/elementary.git/commit/?id=8a4d75e8798bc2fdda4899b2722fe0f5b5cf30cb

commit 8a4d75e8798bc2fdda4899b2722fe0f5b5cf30cb
Author: maxerba 
Date:   Fri Jan 16 12:34:13 2015 +0100

Updating italian translation
---
 po/it.po | 86 +---
 1 file changed, 45 insertions(+), 41 deletions(-)

diff --git a/po/it.po b/po/it.po
index 6ffbef7..405c656 100644
--- a/po/it.po
+++ b/po/it.po
@@ -1,13 +1,13 @@
 # Italian translation for Elementary.
 # This file is put in the public domain.
 # Massimo Maiurana , 2011.
-#: src/lib/elm_config.c:3207
+#: src/lib/elm_config.c:3174
 msgid ""
 msgstr ""
 "Project-Id-Version: Elementary\n"
 "Report-Msgid-Bugs-To: enlightenment-devel@lists.sourceforge.net\n"
-"POT-Creation-Date: 2014-11-07 09:26+0900\n"
-"PO-Revision-Date: 2014-10-08 19:10+0200\n"
+"POT-Creation-Date: 2015-01-15 19:55+0100\n"
+"PO-Revision-Date: 2015-01-16 12:33+0100\n"
 "Last-Translator: Massimo Maiurana \n"
 "Language-Team: General\n"
 "Language: it\n"
@@ -15,52 +15,56 @@ msgstr ""
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
 
-#: src/lib/elc_fileselector.c:1403
+#: src/lib/elc_fileselector.c:1449
 msgid "Up"
 msgstr "Su"
 
-#: src/lib/elc_fileselector.c:1418
+#: src/lib/elc_fileselector.c:1464
 msgid "Home"
 msgstr "Home"
 
-#: src/lib/elc_fileselector.c:1637 src/lib/elm_entry.c:1477
-#: src/lib/elm_entry.c:1502
+#: src/lib/elc_fileselector.c:1527
+msgid "Search"
+msgstr "Cerca"
+
+#: src/lib/elc_fileselector.c:1693 src/lib/elm_entry.c:1487
+#: src/lib/elm_entry.c:1512
 msgid "Cancel"
 msgstr "Annulla"
 
-#: src/lib/elc_fileselector.c:1646
+#: src/lib/elc_fileselector.c:1702
 msgid "OK"
 msgstr "OK"
 
-#: src/lib/elc_multibuttonentry.c:604
+#: src/lib/elc_multibuttonentry.c:611
 msgid "multi button entry label"
 msgstr "etichetta voce multibottone"
 
-#: src/lib/elc_multibuttonentry.c:625
+#: src/lib/elc_multibuttonentry.c:633
 msgid "multi button entry item"
 msgstr "oggetto voce multibottone"
 
-#: src/lib/elc_multibuttonentry.c:1490
+#: src/lib/elc_multibuttonentry.c:1507
 msgid "multi button entry"
 msgstr "voce multibottone"
 
-#: src/lib/elc_naviframe.c:430
+#: src/lib/elc_naviframe.c:431
 msgid "Title"
 msgstr "Titolo"
 
-#: src/lib/elc_naviframe.c:957 src/lib/elc_naviframe.c:1155
+#: src/lib/elc_naviframe.c:957 src/lib/elc_naviframe.c:1156
 msgid "Back"
 msgstr "Indietro"
 
-#: src/lib/elc_naviframe.c:1246
+#: src/lib/elc_naviframe.c:1249
 msgid "Next"
 msgstr "Avanti"
 
-#: src/lib/elc_popup.c:258 src/lib/elc_popup.c:880
+#: src/lib/elc_popup.c:261 src/lib/elc_popup.c:868
 msgid "Popup Title"
 msgstr "Titolo popup"
 
-#: src/lib/elc_popup.c:268 src/lib/elc_popup.c:946
+#: src/lib/elc_popup.c:271 src/lib/elc_popup.c:934
 msgid "Popup Body Text"
 msgstr "Testo corpo popup"
 
@@ -72,10 +76,10 @@ msgstr "Bolla"
 msgid "Clicked"
 msgstr "Cliccato"
 
-#: src/lib/elm_button.c:271 src/lib/elm_check.c:235 src/lib/elm_gengrid.c:770
-#: src/lib/elm_genlist.c:1518 src/lib/elm_list.c:2054 src/lib/elm_radio.c:256
-#: src/lib/elm_segment_control.c:521 src/lib/elm_spinner.c:578
-#: src/lib/elm_toolbar.c:2208
+#: src/lib/elm_button.c:271 src/lib/elm_check.c:235 src/lib/elm_gengrid.c:814
+#: src/lib/elm_genlist.c:1576 src/lib/elm_list.c:2172 src/lib/elm_radio.c:256
+#: src/lib/elm_segment_control.c:525 src/lib/elm_spinner.c:578
+#: src/lib/elm_toolbar.c:2220
 msgid "State: Disabled"
 msgstr "Stato: disabilitato"
 
@@ -156,51 +160,51 @@ msgstr "Stato: modificabile"
 msgid "Clock"
 msgstr "Orologio"
 
-#: src/lib/elm_colorselector.c:1367
+#: src/lib/elm_colorselector.c:1395
 msgid "color selector palette item"
 msgstr "oggetto palette selezione colore"
 
-#: src/lib/elm_config.c:3223
+#: src/lib/elm_config.c:3190
 msgid "default:LTR"
 msgstr "predefintito: LTR"
 
-#: src/lib/elm_dayselector.c:396
+#: src/lib/elm_dayselector.c:404
 msgid "day selector item"
 msgstr "oggetto selettore giorno"
 
-#: src/lib/elm_diskselector.c:675
+#: src/lib/elm_diskselector.c:693
 msgid "diskselector item"
 msgstr "selettore disco"
 
-#: src/lib/elm_entry.c:1464
+#: src/lib/elm_entry.c:1474
 msgid "Copy"
 msgstr "Copia"
 
-#: src/lib/elm_entry.c:1469
+#: src/lib/elm_entry.c:1479
 msgid "Cut"
 msgstr "Taglia"
 
-#: src/lib/elm_entry.c:1473 src/lib/elm_entry.c:1496
+#: src/lib/elm_entry.c:1483 src/lib/elm_entry.c:1506
 msgid "Paste"
 msgstr "Incolla"
 
-#: src/lib/elm_entry.c:1489
+#: src/lib/elm_entry.c:1499
 msgid "Select"
 msgstr "Seleziona"
 
-#: src/lib/elm_entry.c:3476
+#: src/lib/elm_entry.c:3488
 msgid "Entry"
 msgstr "Voce"
 
-#: src/lib/elm_gengrid.c:800
+#: src/lib/elm_gengrid.c:844
 msgid "Gengrid Item"
 msgstr "oggetto griglia generica"
 
-#: src/lib/elm_index.c:91
+#: src/lib/elm_index.c:93
 msgid "Index"
 msgstr "Indice"
 
-#: src/lib/elm_index.c:118
+#: src/lib/elm_index.c:121
 msgid "Index Item"
 msgstr "oggetto indice"
 
@@ -236,19 +240,19 @@ msgstr "barra a

Re: [E-devel] [EGIT] [core/enlightenment] master 01/01: wl_drm: Fix creation of the ecore_evas_gl_drm

2015-01-16 Thread Stefan Schmidt
Hello.

On 16/01/15 10:12, Kabeer Ahmed Khan wrote:
>Hi Stefan
>
>
>Sorry man this was my mistake. It was most silly one and I will make sure
>this never happens in future.
>
Mistakes happen, thats normal. I just wanted to point out that we should
asked for a new version in phab so the contributor can fix it on his/her
own instead of putting it in and fixing it directly afterwards.

regards
Stefan Schmidt

--
New Year. New Location. New Benefits. New Data Center in Ashburn, VA.
GigeNET is offering a free month of service with a new server in Ashburn.
Choose from 2 high performing configs, both with 100TB of bandwidth.
Higher redundancy.Lower latency.Increased capacity.Completely compliant.
http://p.sf.net/sfu/gigenet
___
enlightenment-devel mailing list
enlightenment-devel@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/enlightenment-devel


[EGIT] [core/elementary] master 01/01: tests: actually run the main loop properly to be able to enter in idle state.

2015-01-16 Thread Cedric BAIL
cedric pushed a commit to branch master.

http://git.enlightenment.org/core/elementary.git/commit/?id=f176c1589ccfc518858978a7f08735db7911b130

commit f176c1589ccfc518858978a7f08735db7911b130
Author: Cedric BAIL 
Date:   Fri Jan 16 14:29:23 2015 +0100

tests: actually run the main loop properly to be able to enter in idle 
state.

Note that the iterate function will never trigger the idler that are 
registered
in Ecore. That's by definition. I changed the code to actually use the full
main loop and trigger the change detection on idle enterer. That should be 
enough
for Elementary as all idler should logically affect the visual aspect of 
something
at some point and exit idle.

Thanks marcel-hollerb...@t-online.de for helping me debug this issue.
---
 src/tests/elm_test_helper.c | 40 +++-
 1 file changed, 23 insertions(+), 17 deletions(-)

diff --git a/src/tests/elm_test_helper.c b/src/tests/elm_test_helper.c
index 6e11ef3..81ab0d1 100644
--- a/src/tests/elm_test_helper.c
+++ b/src/tests/elm_test_helper.c
@@ -5,35 +5,41 @@
 #include 
 #include "elm_suite.h"
 
-typedef struct _Callback_Data
+static Eina_Bool
+timer_expired_cb(void *user_data)
 {
-   Ecore_Timer *timer;
-   Eina_Bool did_timeout;
-} Callback_Data;
+   Eina_Bool *did_timeout = user_data;
+
+   *did_timeout = EINA_TRUE;
+   ecore_main_loop_quit();
+
+   return EINA_TRUE;
+}
 
 static Eina_Bool
-timer_expired_cb(void *user_data)
+idler_done_cb(void *user_data)
 {
-   Callback_Data *data = user_data;
-   data->did_timeout = EINA_TRUE;
-   data->timer = NULL;
+   Eina_Bool *done = user_data;
+
+   if (*done) ecore_main_loop_quit();
 
-   return ECORE_CALLBACK_CANCEL;
+   return EINA_TRUE;
 }
 
 Eina_Bool
 elm_test_helper_wait_flag(double in, Eina_Bool *done)
 {
-   Callback_Data data;
+   Eina_Bool did_timeout = EINA_FALSE;
+   Ecore_Timer *tm;
+   Ecore_Idle_Enterer *idle;
 
-   data.did_timeout = EINA_FALSE;
-   data.timer = ecore_timer_add(in, timer_expired_cb, &data);
+   tm = ecore_timer_add(in, timer_expired_cb, &did_timeout);
+   idle = ecore_idle_enterer_add(idler_done_cb, done);
 
-   while (*done == EINA_FALSE && data.did_timeout == EINA_FALSE)
- ecore_main_loop_iterate();
+   ecore_main_loop_begin();
 
-   if (data.timer)
- ecore_timer_del(data.timer);
+   ecore_idle_enterer_del(idle);
+   ecore_timer_del(tm);
 
-   return !data.did_timeout;
+   return !did_timeout;
 }

-- 




[EGIT] [core/efl] master 01/01: examples/eina_inarray: Remove unused variables.

2015-01-16 Thread Stefan Schmidt
stefan pushed a commit to branch master.

http://git.enlightenment.org/core/efl.git/commit/?id=82249b5b50d9640ed1ebd363cf3cca92f5bcb255

commit 82249b5b50d9640ed1ebd363cf3cca92f5bcb255
Author: Stefan Schmidt 
Date:   Fri Jan 16 10:39:24 2015 +0100

examples/eina_inarray: Remove unused variables.
---
 src/examples/eina/eina_inarray_03.c | 3 +--
 1 file changed, 1 insertion(+), 2 deletions(-)

diff --git a/src/examples/eina/eina_inarray_03.c 
b/src/examples/eina/eina_inarray_03.c
index f0be8fd..177ae50 100644
--- a/src/examples/eina/eina_inarray_03.c
+++ b/src/examples/eina/eina_inarray_03.c
@@ -12,8 +12,7 @@ cmp(const void *a, const void *b)
 int main(int argc EINA_UNUSED, char **argv EINA_UNUSED)
 {
Eina_Inarray *iarr;
-   char ch, *ch2;
-   int a, *b, pos;
+   int a, *b;
 
eina_init();
iarr = eina_inarray_new(sizeof(int), 0);

-- 




[EGIT] [core/efl] master 01/01: ecore-wayland: Don't crash if we have no input->cursor_name

2015-01-16 Thread Christopher Michael
devilhorns pushed a commit to branch master.

http://git.enlightenment.org/core/efl.git/commit/?id=ade7482ee2336d4016ffe17d8569a1b0bb261c70

commit ade7482ee2336d4016ffe17d8569a1b0bb261c70
Author: Chris Michael 
Date:   Fri Jan 16 10:35:06 2015 -0500

ecore-wayland: Don't crash if we have no input->cursor_name

Summary: If we are using a touchscreen, there will be no pointer and
thus no cursor_name to use. Trap for that case by checking if
input->cursor_name is valid.

@fix

Signed-off-by: Chris Michael 
---
 src/lib/ecore_wayland/ecore_wl_window.c | 2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)

diff --git a/src/lib/ecore_wayland/ecore_wl_window.c 
b/src/lib/ecore_wayland/ecore_wl_window.c
index 55c7097..1db8ed0 100644
--- a/src/lib/ecore_wayland/ecore_wl_window.c
+++ b/src/lib/ecore_wayland/ecore_wl_window.c
@@ -706,7 +706,7 @@ ecore_wl_window_cursor_from_name_set(Ecore_Wl_Window *win, 
const char *cursor_na
 
eina_stringshare_replace(&win->cursor_name, cursor_name);
 
-   if (strcmp(input->cursor_name, win->cursor_name))
+   if ((input->cursor_name) && (strcmp(input->cursor_name, win->cursor_name)))
  ecore_wl_input_cursor_from_name_set(input, cursor_name);
 }
 

-- 




[EGIT] [core/elementary] master 01/01: tests: add coverage support.

2015-01-16 Thread Cedric BAIL
cedric pushed a commit to branch master.

http://git.enlightenment.org/core/elementary.git/commit/?id=ef8f767f0cfb558b75d5b2533c57c97b050a7830

commit ef8f767f0cfb558b75d5b2533c57c97b050a7830
Author: Cedric BAIL 
Date:   Fri Jan 16 16:39:37 2015 +0100

tests: add coverage support.

And our current score is 19% functions coverage for Elementary.
---
 .gitignore  |  3 +++
 Makefile.am | 34 +++---
 configure.ac| 50 +-
 src/Makefile.am |  2 +-
 src/bin/Makefile.am |  8 
 5 files changed, 88 insertions(+), 9 deletions(-)

diff --git a/.gitignore b/.gitignore
index 4c0b0c7..5427997 100644
--- a/.gitignore
+++ b/.gitignore
@@ -11,6 +11,8 @@
 *.lo
 *.o
 *.la
+*.gcda
+*.gcno
 .libs
 .deps
 .*.swp
@@ -57,3 +59,4 @@ tags
 /config/mobile/*.src
 /config/standard/*.src
 Session.vim
+/coverage/
diff --git a/Makefile.am b/Makefile.am
index 70f7a92..30de680 100644
--- a/Makefile.am
+++ b/Makefile.am
@@ -54,9 +54,6 @@ po/Rules-quot
 
 endif
 
-
-
-
 EXTRA_DIST = \
 README \
 AUTHORS \
@@ -125,3 +122,34 @@ doc:
 screenshots: all
@echo "entering src/examples/"
$(MAKE) -C src/examples screenshots
+
+if ELEMENTARY_ENABLE_COVERAGE
+
+lcov-reset:
+   @rm -rf $(top_builddir)/coverage
+   @find $(top_builddir) -name "*.gcda" -delete
+   @lcov --zerocounters --directory $(top_builddir)
+
+lcov-report:
+   @mkdir $(top_builddir)/coverage
+   lcov --capture --compat-libtool --no-external --output-file 
$(top_builddir)/coverage/coverage.info --directory $(top_builddir) 
--base-directory $(top_srcdir)/src/lib/
+   lcov --remove $(top_builddir)/coverage/coverage.info '*.h' 
--output-file $(top_builddir)/coverage/coverage.cleaned.info
+   lcov --remove $(top_builddir)/coverage/coverage.cleaned.info 
'*/elm_test_*' --output-file $(top_builddir)/coverage/coverage.cleaned2.info
+   lcov --remove $(top_builddir)/coverage/coverage.cleaned2.info 
'*/elm_suite.c' --output-file $(top_builddir)/coverage/coverage.cleaned3.info
+   lcov --remove $(top_builddir)/coverage/coverage.cleaned3.info '*NONE*' 
--output-file $(top_builddir)/coverage/coverage.cleaned4.info
+   genhtml --branch-coverage -t "$(PACKAGE_STRING)" -o 
$(top_builddir)/coverage/html $(top_builddir)/coverage/coverage.cleaned4.info
+   @echo "Coverage Report at $(top_builddir)/coverage/html"
+
+endif
+
+if ELEMENTARY_ENABLE_TESTS
+
+lcov-check:
+if ELEMENTARY_ENABLE_COVERAGE
+   @$(MAKE) $(AM_MAKEFLAGS) lcov-reset
+endif
+   @$(MAKE) $(AM_MAKEFLAGS) check
+if ELEMENTARY_ENABLE_COVERAGE
+   @$(MAKE) $(AM_MAKEFLAGS) lcov-report
+endif
+endif
diff --git a/configure.ac b/configure.ac
index 5804d6b..5b075e8 100644
--- a/configure.ac
+++ b/configure.ac
@@ -39,10 +39,32 @@ AC_ARG_ENABLE([cxx-bindings],
 # Tests
 
 AC_ARG_WITH([tests],
-   [AS_HELP_STRING([--with-tests=none|regular],
-   [choose elementary testing method: regular or 
none.(coverage will be supported)@<:@default=none@:>@])],
+   [AS_HELP_STRING([--with-tests=none|regular|coverate],
+   [choose elementary testing method: regular, coverage or 
none @<:@default=none@:>@])],
[build_tests=${withval}],
-   [build_tests=none])
+   [build_tests=auto])
+
+want_coverage="no"
+want_tests="no"
+case "${build_tests}" in
+   auto)
+ if test "${build_profile}" = "dev"; then
+want_tests="yes"
+ fi
+ ;;
+   regular)
+ want_tests="yes"
+ ;;
+   coverage)
+ want_tests="yes"
+ want_coverage="yes"
+ ;;
+   no*)
+ ;;
+   *)
+ AC_MSG_ERROR([Unknown build tests option: --with-tests=${build_tests}])
+ ;;
+esac
 
 # Elementary base dir
 
@@ -336,10 +358,28 @@ ELEMENTARY_PC_LIBS="${ELEMENTARY_PC_LIBS} 
${requirement_elm_libs}"
 AC_SUBST([requirement_elm_pc])
 
 # check unit testing library
-if test "${build_tests}" = "regular"; then
+if test "${want_tests}" = "yes"; then
PKG_CHECK_MODULES([CHECK], [check >= 0.9.5])
 fi
-AM_CONDITIONAL([ENABLE_ELEMENTARY_TESTS], [test "${build_tests}" = "regular"])
+AM_CONDITIONAL([ELEMENTARY_ENABLE_TESTS], [test "${want_tests}" = "yes"])
+
+# lcov
+if test "${want_coverage}" = "yes" ; then
+   AC_CHECK_PROG([have_lcov], [lcov], [yes], [no])
+   if test "x${have_lcov}" = "xyes" ; then
+  ELEMENTARY_CFLAGS="${ELEMENTARY_CFLAGS} -fprofile-arcs -ftest-coverage"
+  ELEMENTARY_LIBS="${ELEMENTARY_LIBS} -lgcov"
+  if test "x${prefer_assert}" = "xno"; then
+ ELEMENTARY_CFLAGS="${ELEMENTARY_CFLAGS} -DNDEBUG"
+  else
+ ELEMENTARY_CFLAGS="${ELEMENTARY_CFLAGS} -g -O0 -DDEBUG"
+  fi
+   else
+  AC_MSG_ERROR([lcov is not found])
+   fi
+fi
+
+AM_CONDITIONAL([ELEMENTARY_ENABLE_COVERAGE], [test "${want_coverage}" = "yes"])
 
 
 ### Checks for header files
diff --git a/src/Makefile.am b/src/Makefile.am
index 7f9e3c3..bc0e30f 100644
--- a/src/Makefile.am
+++ b/src/Makefile.am
@@ -9,6 +9,6 @@ endif
 
 SUBDIRS += exampl

Re: [E-devel] Help updating a patch for E17.6

2015-01-16 Thread Jeff Hoogland
For reference - I updated the patch I linked to shortly after I sent this
email. Turns out I had the wrong version of the patch. Once I had the
latest version it was applying properly.

On Thu, Jan 15, 2015 at 4:59 AM, Daniel Kolesa  wrote:

> On Thu, Jan 15, 2015 at 10:51 AM, Daniel Kolesa 
> wrote:
>
> > On Thu, Jan 15, 2015 at 10:12 AM, Daniel Kolesa 
> > wrote:
> >
> >> On Thu, Jan 15, 2015 at 4:52 AM, Jeff Hoogland 
> >> wrote:
> >>
> >>> Howdy Folks,
> >>>
> >>> Before he dropped off the face of the planet, Kukko had written this
> >>> patch
> >>> <
> >>>
> https://github.com/JeffHoogland/bodhibuildscripts/blob/master/patches/bodhi_e17.diff
> >>> >
> >>> that
> >>> added some menu entries and edit the E17 Wizard for Bodhi. It compiled
> a
> >>> few months ago, but as of EFL 1.12.2 I am now getting this compile
> error:
> >>>
> >>> e_int_menus.c: In function ‘_e_int_menus_bodhi_about’:
> >>> e_int_menus.c:666:34: error: ‘E_Zone’ has no member named ‘comp’ dlg =
> >>> e_obj_dialog_new(m->zone->comp, BODHI_ABOUT_TITLE, "E", "_about"); ^
> >>> e_int_menus.c: In function ‘_e_int_menus_clients_title_abbrv’:
> >>> e_int_menus.c:1459:7: warning: ‘eina_unicode_utf8_get_next’ is
> deprecated
> >>> (declared at /usr/include/eina-1/eina/eina_unicode.h:143)
> >>> [-Wdeprecated-declarations] eina_unicode_utf8_get_next(title, &len); ^
> >>> make[5]: *** [enlightenment-e_int_menus.o] Error 1 make[5]: Leaving
> >>> directory `/home/jeff/bodhi_debs/20150114/e17-20150114/src/bin'
> make[4]:
> >>> *** [all-recursive] Error 1 make[4]: Leaving directory
> >>> `/home/jeff/bodhi_debs/20150114/e17-20150114/src/bin' make[3]: ***
> >>> [all-recursive] Error 1 make[3]: Leaving directory
> >>> `/home/jeff/bodhi_debs/20150114/e17-20150114/src' make[2]: ***
> >>> [all-recursive] Error 1 make[2]: Leaving directory
> >>> `/home/jeff/bodhi_debs/20150114/e17-20150114' make[1]: *** [all] Error
> 2
> >>> make[1]: Leaving directory
> `/home/jeff/bodhi_debs/20150114/e17-20150114'
> >>>
> >>> The patch is applied against the E17.6 source from here
> >>> . If anyone who is more
> >>> familiar with C/E17.6 source than I am has a chance to make this
> compile
> >>> with the latest EFL I would be very grateful.
> >>>
> >>
> >> Yo,
> >>
> >> I take a look at the patch too much but how about you just try replacing
> >> all instances of eina_unicode_utf8_get_next with
> >> eina_unicode_utf8_next_get? (search and replace should do) If there are
> no
> >> other errors it should work.
> >>
> >
> > Also nevermind me... my brain for some reason completely ignored half of
> > the error :P
> >
>
> I just took a closer look at the patch. It appears that what you've applied
> doesn't really match what you've linked.
>
> Your version you're trying to compile is trying to do
> "e_obj_dialog_new(m->zone->comp, BODHI_ABOUT_TITLE, "E", "_about")" while
> the patch you linked actually does "e_obj_dialog_new(m->zone->container,
> BODHI_ABOUT_TITLE, "E", "_about");".
>
>
> >
> >
> >>
> >>
> >>>
> >>> Regards,
> >>> --
> >>> ~Jeff Hoogland 
> >>> My Projects on GitHub 
> >>>
> >>>
> --
> >>> New Year. New Location. New Benefits. New Data Center in Ashburn, VA.
> >>> GigeNET is offering a free month of service with a new server in
> Ashburn.
> >>> Choose from 2 high performing configs, both with 100TB of bandwidth.
> >>> Higher redundancy.Lower latency.Increased capacity.Completely
> compliant.
> >>> http://p.sf.net/sfu/gigenet
> >>> ___
> >>> enlightenment-devel mailing list
> >>> enlightenment-devel@lists.sourceforge.net
> >>> https://lists.sourceforge.net/lists/listinfo/enlightenment-devel
> >>>
> >>
> >> D5
> >>
> >
> >
>
> --
> New Year. New Location. New Benefits. New Data Center in Ashburn, VA.
> GigeNET is offering a free month of service with a new server in Ashburn.
> Choose from 2 high performing configs, both with 100TB of bandwidth.
> Higher redundancy.Lower latency.Increased capacity.Completely compliant.
> http://p.sf.net/sfu/gigenet
> ___
> enlightenment-devel mailing list
> enlightenment-devel@lists.sourceforge.net
> https://lists.sourceforge.net/lists/listinfo/enlightenment-devel
>



-- 
~Jeff Hoogland 
My Projects on GitHub 
--
New Year. New Location. New Benefits. New Data Center in Ashburn, VA.
GigeNET is offering a free month of service with a new server in Ashburn.
Choose from 2 high performing configs, both with 100TB of bandwidth.
Higher redundancy.Lower latency.Increased capacity.Completely compliant.
http://p.sf.net/sfu/gigenet

[EGIT] [enlightenment/modules/extramenu] master 01/01: Extramenu module revamped.

2015-01-16 Thread Dave Andreoli
davemds pushed a commit to branch master.

http://git.enlightenment.org/enlightenment/modules/extramenu.git/commit/?id=9da09c26718bbf73c03c1792b1ecc1d467ac24c9

commit 9da09c26718bbf73c03c1792b1ecc1d467ac24c9
Author: Dave Andreoli 
Date:   Fri Jan 16 19:54:10 2015 +0100

Extramenu module revamped.

Info on this new (old) module can be found at:
https://phab.enlightenment.org/w/emodules/extramenu/
---
 AUTHORS|   1 +
 COPYING| 674 +
 COPYING.LESSER | 165 
 ChangeLog  |   0
 INSTALL| 234 +
 Makefile.am|  25 ++
 NEWS   |   0
 README | 102 
 autogen.sh |  15 ++
 configure.ac   |  63 +
 e-module-extramenu.edc |  22 ++
 icon.png   | Bin 0 -> 3071 bytes
 m4/ac_attribute.m4 |  14 +
 module.desktop.in  |   6 +
 src/Makefile.am|  18 ++
 src/e_mod_main.c   | 239 ++
 src/e_mod_main.h   |  46 
 17 files changed, 1624 insertions(+)

diff --git a/AUTHORS b/AUTHORS
new file mode 100644
index 000..71886bd
--- /dev/null
+++ b/AUTHORS
@@ -0,0 +1 @@
+Dave Andreoli 
diff --git a/COPYING b/COPYING
new file mode 100644
index 000..94a9ed0
--- /dev/null
+++ b/COPYING
@@ -0,0 +1,674 @@
+GNU GENERAL PUBLIC LICENSE
+   Version 3, 29 June 2007
+
+ Copyright (C) 2007 Free Software Foundation, Inc. 
+ Everyone is permitted to copy and distribute verbatim copies
+ of this license document, but changing it is not allowed.
+
+Preamble
+
+  The GNU General Public License is a free, copyleft license for
+software and other kinds of works.
+
+  The licenses for most software and other practical works are designed
+to take away your freedom to share and change the works.  By contrast,
+the GNU General Public License is intended to guarantee your freedom to
+share and change all versions of a program--to make sure it remains free
+software for all its users.  We, the Free Software Foundation, use the
+GNU General Public License for most of our software; it applies also to
+any other work released this way by its authors.  You can apply it to
+your programs, too.
+
+  When we speak of free software, we are referring to freedom, not
+price.  Our General Public Licenses are designed to make sure that you
+have the freedom to distribute copies of free software (and charge for
+them if you wish), that you receive source code or can get it if you
+want it, that you can change the software or use pieces of it in new
+free programs, and that you know you can do these things.
+
+  To protect your rights, we need to prevent others from denying you
+these rights or asking you to surrender the rights.  Therefore, you have
+certain responsibilities if you distribute copies of the software, or if
+you modify it: responsibilities to respect the freedom of others.
+
+  For example, if you distribute copies of such a program, whether
+gratis or for a fee, you must pass on to the recipients the same
+freedoms that you received.  You must make sure that they, too, receive
+or can get the source code.  And you must show them these terms so they
+know their rights.
+
+  Developers that use the GNU GPL protect your rights with two steps:
+(1) assert copyright on the software, and (2) offer you this License
+giving you legal permission to copy, distribute and/or modify it.
+
+  For the developers' and authors' protection, the GPL clearly explains
+that there is no warranty for this free software.  For both users' and
+authors' sake, the GPL requires that modified versions be marked as
+changed, so that their problems will not be attributed erroneously to
+authors of previous versions.
+
+  Some devices are designed to deny users access to install or run
+modified versions of the software inside them, although the manufacturer
+can do so.  This is fundamentally incompatible with the aim of
+protecting users' freedom to change the software.  The systematic
+pattern of such abuse occurs in the area of products for individuals to
+use, which is precisely where it is most unacceptable.  Therefore, we
+have designed this version of the GPL to prohibit the practice for those
+products.  If such problems arise substantially in other domains, we
+stand ready to extend this provision to those domains in future versions
+of the GPL, as needed to protect the freedom of users.
+
+  Finally, every program is threatened constantly by software patents.
+States should not allow patents to restrict development and use of
+software on general-purpose computers, but in those that do, we wish to
+avoid the special danger that patents applied to a free program could
+make it effectively proprietary.  To prevent this, the GPL assures that
+patents cannot be used to render the program non-free.
+
+  The precise t

[EGIT] [enlightenment/modules/extramenu] master 01/01: warning--, gitignore++

2015-01-16 Thread Dave Andreoli
davemds pushed a commit to branch master.

http://git.enlightenment.org/enlightenment/modules/extramenu.git/commit/?id=ec4edc018a0d0b34e14dd90282d2ab939f3f7c3a

commit ec4edc018a0d0b34e14dd90282d2ab939f3f7c3a
Author: Dave Andreoli 
Date:   Fri Jan 16 19:59:59 2015 +0100

warning--, gitignore++
---
 .gitignore  | 33 +
 src/Makefile.am |  2 +-
 2 files changed, 34 insertions(+), 1 deletion(-)

diff --git a/.gitignore b/.gitignore
new file mode 100644
index 000..53762e5
--- /dev/null
+++ b/.gitignore
@@ -0,0 +1,33 @@
+Makefile
+Makefile.in
+aclocal.m4
+autom4te.cache/
+compile
+config.guess
+config.h
+config.h.in
+config.log
+config.status
+config.sub
+configure
+depcomp
+e-module-extramenu.edj
+install-sh
+libtool
+ltmain.sh
+m4/libtool.m4
+m4/ltoptions.m4
+m4/ltsugar.m4
+m4/ltversion.m4
+m4/lt~obsolete.m4
+missing
+module.desktop
+src/.deps/
+src/.libs/
+src/Makefile
+src/Makefile.in
+src/e_mod_main.lo
+src/e_mod_main.o
+src/module.la
+stamp-h1
+
diff --git a/src/Makefile.am b/src/Makefile.am
index 11fb745..63586a9 100644
--- a/src/Makefile.am
+++ b/src/Makefile.am
@@ -1,6 +1,6 @@
 MAINTAINERCLEANFILES = Makefile.in
 
-INCLUDES = -Wall -I. \
+AM_CPPFLAGS = -Wall -I. \
   -I$(top_srcdir) \
   -I$(includedir) \
   @E_CFLAGS@

-- 




[EGIT] [apps/ephoto] master 01/01: Ephoto: Add the ability to DND from the grid to other applications.

2015-01-16 Thread Stephen Houston
okra pushed a commit to branch master.

http://git.enlightenment.org/apps/ephoto.git/commit/?id=a413df8c489ec6d445d071496128beba5d26ac98

commit a413df8c489ec6d445d071496128beba5d26ac98
Author: Stephen Houston 
Date:   Fri Jan 16 13:39:02 2015 -0600

Ephoto: Add the ability to DND from the grid to other applications.
---
 src/bin/ephoto_thumb_browser.c | 183 +
 1 file changed, 183 insertions(+)

diff --git a/src/bin/ephoto_thumb_browser.c b/src/bin/ephoto_thumb_browser.c
index 0080f91..421bdbd 100644
--- a/src/bin/ephoto_thumb_browser.c
+++ b/src/bin/ephoto_thumb_browser.c
@@ -8,6 +8,15 @@
 
 #define PARENT_DIR "Up"
 
+#define FILESEP "file://"
+#define FILESEP_LEN sizeof(FILESEP) - 1
+
+#define DRAG_TIMEOUT 0.3
+#define ANIM_TIME 0.2
+
+static Eina_Bool _5s_cancel = EINA_FALSE;
+static Ecore_Timer *_5s_timeout = NULL;
+
 typedef struct _Ephoto_Thumb_Browser Ephoto_Thumb_Browser;
 
 struct _Ephoto_Thumb_Browser
@@ -288,6 +297,178 @@ _key_down(void *data, Evas *e __UNUSED__, Evas_Object *o 
__UNUSED__, void *event
  }
 }
 
+static Eina_Bool
+_5s_timeout_gone(void *data)
+{
+   elm_drag_cancel(data);
+   _5s_timeout = NULL;
+   return ECORE_CALLBACK_CANCEL;
+}
+
+static void
+_dnd_drag_start(void *data EINA_UNUSED, Evas_Object *obj)
+{
+   if (_5s_cancel)
+ _5s_timeout = ecore_timer_add(5.0, _5s_timeout_gone, obj);
+}
+
+static void
+_dnd_drag_done(void *data, Evas_Object *obj EINA_UNUSED, Eina_Bool doaccept 
EINA_UNUSED)
+{
+   if (_5s_cancel)
+ {
+ecore_timer_del(_5s_timeout);
+_5s_timeout = NULL;
+ }
+
+   eina_list_free(data);
+   return;
+}
+
+static const char *
+_dnd_drag_data_build(Eina_List **items)
+{
+   const char *drag_data = NULL;
+   if (*items)
+ {
+Eina_List *l;
+Elm_Object_Item *it;
+Ephoto_Entry *e;
+unsigned int len = 0;
+
+EINA_LIST_FOREACH(*items, l, it)
+  {
+ e = elm_object_item_data_get(it);
+ if (e->path)
+   len += strlen(e->path);
+  }
+
+drag_data = malloc(len + eina_list_count(*items) * (FILESEP_LEN + 1) + 
1);
+strcpy((char *) drag_data, "");
+
+EINA_LIST_FOREACH(*items, l, it)
+  {
+ e = elm_object_item_data_get(it);
+ if (e->path)
+   {
+  strcat((char *) drag_data, FILESEP);
+  strcat((char *) drag_data, e->path);
+  strcat((char *) drag_data, "\n");
+   }
+  }
+ }
+   return drag_data;
+}
+
+static Evas_Object *
+_dnd_create_icon(void *data, Evas_Object *win, Evas_Coord *xoff, Evas_Coord 
*yoff)
+{
+   Evas_Object *icon = NULL;
+   Evas_Object *o = elm_object_item_part_content_get(data, "elm.swallow.icon");
+
+   if (o)
+ {
+int xm, ym, w = 30, h = 30;
+const char *f;
+const char *g;
+elm_image_file_get(o, &f, &g);
+evas_pointer_canvas_xy_get(evas_object_evas_get(o), &xm, &ym);
+if (xoff) *xoff = xm - (w/2);
+if (yoff) *yoff = ym - (h/2);
+icon = elm_icon_add(win);
+elm_image_file_set(icon, f, g);
+evas_object_size_hint_align_set(icon, EVAS_HINT_FILL, EVAS_HINT_FILL);
+evas_object_size_hint_weight_set(icon, EVAS_HINT_EXPAND, 
EVAS_HINT_EXPAND);
+if (xoff && yoff) evas_object_move(icon, *xoff, *yoff);
+evas_object_resize(icon, w, h);
+ }
+
+   return icon;
+}
+
+static Eina_List *
+_dnd_icons_get(void *data)
+{
+   Eina_List *l;
+   Eina_List *icons = NULL;
+   Evas_Coord xm, ym;
+
+   evas_pointer_canvas_xy_get(evas_object_evas_get(data), &xm, &ym);
+   Eina_List *items = eina_list_clone(elm_gengrid_selected_items_get(data));
+   Elm_Object_Item *gli = elm_gengrid_at_xy_item_get(data, xm, ym, NULL, NULL);
+   if (gli)
+ {
+void *p = eina_list_search_sorted(items, _entry_cmp, gli);
+if (!p)
+  items = eina_list_append(items, gli);
+ }
+
+   EINA_LIST_FOREACH(items, l, gli)
+ {
+Evas_Object *o = elm_object_item_part_content_get(gli, 
"elm.swallow.icon");
+
+if (o)
+  {
+ int x, y, w, h;
+ const char *f, *g;
+ elm_image_file_get(o, &f, &g);
+ Evas_Object *ic = elm_icon_add(data);
+ elm_image_file_set(ic, f, g);
+ evas_object_geometry_get(o, &x, &y, &w, &h);
+ evas_object_size_hint_align_set(ic, EVAS_HINT_FILL, 
EVAS_HINT_FILL);
+ evas_object_size_hint_weight_set(ic, EVAS_HINT_EXPAND, 
EVAS_HINT_EXPAND);
+ evas_object_move(ic, x, y);
+ evas_object_resize(ic, w, h);
+ evas_object_show(ic);
+ icons =  eina_list_append(icons, ic);
+  }
+ }
+
+   eina_list_free(items);
+   return icons;
+}
+
+static const char *
+_dnd_get_drag_data(Evas_Object *obj, Elm_Object_Item *it, Eina_List **items)
+{
+   const char *drag_data = NULL;
+
+   *items = eina_list_clon

[EGIT] [core/enlightenment] master 01/01: add fixme note about desklock timeouts not working in wayland

2015-01-16 Thread Christopher Michael
devilhorns pushed a commit to branch master.

http://git.enlightenment.org/core/enlightenment.git/commit/?id=3520cd58032afb7bc9a63ce6fede5585b2b0b700

commit 3520cd58032afb7bc9a63ce6fede5585b2b0b700
Author: Chris Michael 
Date:   Fri Jan 16 14:44:23 2015 -0500

add fixme note about desklock timeouts not working in wayland

Signed-off-by: Chris Michael 
---
 src/bin/e_desklock.c | 6 ++
 1 file changed, 6 insertions(+)

diff --git a/src/bin/e_desklock.c b/src/bin/e_desklock.c
index b0d8b3e..430e5de 100644
--- a/src/bin/e_desklock.c
+++ b/src/bin/e_desklock.c
@@ -426,6 +426,12 @@ _e_desklock_cb_idle_poller(void *data __UNUSED__)
 #ifndef HAVE_WAYLAND_ONLY
 idle = ecore_x_screensaver_idle_time_get();
 #endif
+/* FIXME: We need to get the idle time from ecore_wayland or 
+ * ecore_drm here. The problem is, we do not link to ecore_drm library 
+ * other than the wl_drm module, and idle_time from ecore_wayland 
+ * library will only work if the comp->ee is created using 
+ * ecore_evas_wayland */
+
 max = e_config->desklock_autolock_idle_timeout;
 if (_e_desklock_ask_presentation_count > 0)
   max *= (1 + _e_desklock_ask_presentation_count);

-- 




[EGIT] [core/elementary] master 01/01: configure: Fix typo in coverage option help text

2015-01-16 Thread Stefan Schmidt
stefan pushed a commit to branch master.

http://git.enlightenment.org/core/elementary.git/commit/?id=7f0e8bc51dfb25377709db9486ae29a1db5bde6e

commit 7f0e8bc51dfb25377709db9486ae29a1db5bde6e
Author: Stefan Schmidt 
Date:   Fri Jan 16 21:16:04 2015 +0100

configure: Fix typo in coverage option help text
---
 configure.ac | 2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)

diff --git a/configure.ac b/configure.ac
index 5b075e8..7408e64 100644
--- a/configure.ac
+++ b/configure.ac
@@ -39,7 +39,7 @@ AC_ARG_ENABLE([cxx-bindings],
 # Tests
 
 AC_ARG_WITH([tests],
-   [AS_HELP_STRING([--with-tests=none|regular|coverate],
+   [AS_HELP_STRING([--with-tests=none|regular|coverage],
[choose elementary testing method: regular, coverage or 
none @<:@default=none@:>@])],
[build_tests=${withval}],
[build_tests=auto])

-- 




[EGIT] [apps/ephoto] master 01/01: Ephoto: Add the ability to DND from the single image to other applications.

2015-01-16 Thread Stephen Houston
okra pushed a commit to branch master.

http://git.enlightenment.org/apps/ephoto.git/commit/?id=d3fbf76314a1d5cf51d1f5e8970918d38a999f1f

commit d3fbf76314a1d5cf51d1f5e8970918d38a999f1f
Author: Stephen Houston 
Date:   Fri Jan 16 14:41:46 2015 -0600

Ephoto: Add the ability to DND from the single image to other applications.
---
 src/bin/ephoto_single_browser.c | 62 -
 1 file changed, 61 insertions(+), 1 deletion(-)

diff --git a/src/bin/ephoto_single_browser.c b/src/bin/ephoto_single_browser.c
index 5f034da..c011e8c 100644
--- a/src/bin/ephoto_single_browser.c
+++ b/src/bin/ephoto_single_browser.c
@@ -2,6 +2,8 @@
 
 #define ZOOM_STEP 0.2
 
+static Ecore_Timer *_1s_hold = NULL;
+
 typedef struct _Ephoto_Single_Browser Ephoto_Single_Browser;
 typedef struct _Ephoto_Viewer Ephoto_Viewer;
 
@@ -41,6 +43,62 @@ _viewer_del(void *data, Evas *e __UNUSED__, Evas_Object *obj 
__UNUSED__, void *e
 }
 
 static Evas_Object *
+_image_create_icon(void *data, Evas_Object *parent, Evas_Coord *xoff, 
Evas_Coord *yoff)
+{
+   Evas_Object *ic;
+   Evas_Object *io = data;
+   const char *f, *g;
+   Evas_Coord x, y, w, h, xm, ym;
+
+   elm_image_file_get(io, &f, &g);
+   ic = elm_image_add(parent);
+   elm_image_file_set(ic, f, g);
+   evas_object_geometry_get(io, &x, &y, &w, &h);
+   evas_object_move(ic, x, y);
+   evas_object_resize(ic, 60, 60);
+   evas_object_show(ic);
+
+   evas_pointer_canvas_xy_get(evas_object_evas_get(io), &xm, &ym);
+   if (xoff) *xoff = xm - 30;
+   if (yoff) *yoff = ym - 30;
+
+   return ic;
+}
+
+static Eina_Bool
+_1s_hold_time(void *data)
+{
+   const char *f;
+   char dd[PATH_MAX];
+
+   Evas_Object *io = data;
+
+   elm_image_file_get(io, &f, NULL);
+   snprintf(dd, sizeof(dd), "file://%s", f);
+
+   elm_drag_start(io, ELM_SEL_FORMAT_IMAGE, dd, ELM_XDND_ACTION_COPY,
+  _image_create_icon, io,
+  NULL, NULL, NULL, NULL, NULL, NULL);
+   _1s_hold = NULL;
+   
+   return ECORE_CALLBACK_CANCEL;
+}
+
+static void
+_image_mouse_down_cb(void *data, Evas *e EINA_UNUSED, Evas_Object *obj 
EINA_UNUSED, void *event_info EINA_UNUSED)
+{
+   Evas_Object *io = data;
+ 
+   _1s_hold = ecore_timer_add(0.5, _1s_hold_time, io);
+}
+
+static void
+_image_mouse_up_cb(void *data EINA_UNUSED, Evas *e EINA_UNUSED, Evas_Object 
*obj EINA_UNUSED, void *event_info EINA_UNUSED)
+{
+   ecore_timer_del(_1s_hold);
+}
+
+static Evas_Object *
 _viewer_add(Evas_Object *parent, const char *path)
 {
Ephoto_Viewer *v = calloc(1, sizeof(Ephoto_Viewer));
@@ -87,9 +145,12 @@ _viewer_add(Evas_Object *parent, const char *path)
err = evas_object_image_load_error_get(elm_image_object_get(v->image));
if (err != EVAS_LOAD_ERROR_NONE) goto load_error;
elm_image_object_size_get(v->image, &w, &h);
+   elm_drop_target_add(v->image, ELM_SEL_FORMAT_IMAGE, NULL, NULL, NULL, NULL, 
NULL, NULL, NULL, NULL);
evas_object_size_hint_min_set(v->image, w, h);
evas_object_size_hint_max_set(v->image, w, h);
elm_table_pack(v->table, v->image, 0, 0, 1, 1);
+   evas_object_event_callback_add(v->image, EVAS_CALLBACK_MOUSE_DOWN, 
_image_mouse_down_cb, v->image);
+   evas_object_event_callback_add(v->image, EVAS_CALLBACK_MOUSE_UP, 
_image_mouse_up_cb, v->image);
evas_object_show(v->image);
 
return obj;
@@ -400,7 +461,6 @@ _last_entry_find(Ephoto_Single_Browser *sb)
return eina_list_last_data_get(sb->ephoto->entries);
 }
 
-
 static void
 _ephoto_single_browser_recalc(Ephoto_Single_Browser *sb)
 {

-- 




[EGIT] [bindings/python/python-efl] master 02/02: Fix doc for theme.theme_list_item_path_get.

2015-01-16 Thread Dave Andreoli
davemds pushed a commit to branch master.

http://git.enlightenment.org/bindings/python/python-efl.git/commit/?id=852d472db85a218325ed562cda092db9997e94f9

commit 852d472db85a218325ed562cda092db9997e94f9
Author: Dave Andreoli 
Date:   Fri Jan 16 22:54:31 2015 +0100

Fix doc for theme.theme_list_item_path_get.

This function is quite of broken in py, the in_search_path param is not used
and should instead be returned along the returned path. That will result in
an api break so Im leaving it as is.
---
 efl/elementary/theme.pyx | 15 ++-
 1 file changed, 6 insertions(+), 9 deletions(-)

diff --git a/efl/elementary/theme.pyx b/efl/elementary/theme.pyx
index fb7b93d..572b3ba 100644
--- a/efl/elementary/theme.pyx
+++ b/efl/elementary/theme.pyx
@@ -432,17 +432,14 @@ cdef class Theme(object):
 def theme_list_item_path_get(f not None, bint in_search_path):
 """Return the full path for a theme element
 
-This returns a string you should free with free() on success, NULL on
-failure. This will search for the given theme element, and if it is a
-full or relative path element or a simple search-able name. The returned
-path is the full path to the file, if searched, and the file exists, or it
-is simply the full path given in the element or a resolved path if
-relative to home. The ``in_search_path`` boolean pointed to is set to
-EINA_TRUE if the file was a search-able file and is in the search path,
-and EINA_FALSE otherwise.
+This returns a string on success or NULL on failure. This will search
+for the given theme element, and if it is a full or relative path
+element or a simple search-able name. The returned path is the full path
+to the file, if searched, and the file exists, or it is simply the full
+path given in the element or a resolved path if relative to home.
 
 :param string f: The theme element name
-:param bool in_search_path: Pointer to a boolean to indicate if item is in 
the search path or not
+:param bool in_search_path: NOT USED
 
 :return: The full path to the file found.
 :rtype: string

diff --git a/src/lib/elm_widget.c b/src/lib/elm_widget.c
index 39aa51c..ee19dbb 100644
--- a/src/lib/elm_widget.c
+++ b/src/lib/elm_widget.c
@@ -411,8 +411,38 @@ _if_focused_revert(Evas_Object *obj,
(top, &newest_focus_order, can_focus_only);
 if (newest)
   {
- elm_object_focus_set(newest, EINA_FALSE);
- elm_object_focus_set(newest, EINA_TRUE);
+ if (newest == top)
+   {
+  ELM_WIDGET_DATA_GET(newest, sd2);
+  if (!sd2) return;
+
+  if (!elm_widget_focus_get(newest))
+elm_widget_focus_steal(newest);
+  else
+{
+   if (sd2->resize_obj && 
elm_widget_focus_get(sd2->resize_obj))
+ elm_widget_focused_object_clear(sd2->resize_obj);
+   else
+ {
+const Eina_List *l;
+Evas_Object *child;
+EINA_LIST_FOREACH(sd2->subobjs, l, child)
+  {
+ if (elm_widget_focus_get(child))
+   {
+  elm_widget_focused_object_clear(child);
+  break;
+   }
+  }
+ }
+}
+  evas_object_focus_set(newest, EINA_TRUE);
+   }
+ else
+   {
+  elm_object_focus_set(newest, EINA_FALSE);
+  elm_object_focus_set(newest, EINA_TRUE);
+   }
   }
  }
 }

--
-- 




[EGIT] [bindings/python/python-efl] master 01/02: Fix documentation for the Theme class

2015-01-16 Thread Dave Andreoli
davemds pushed a commit to branch master.

http://git.enlightenment.org/bindings/python/python-efl.git/commit/?id=b18b8c0d8c3014f76731eb80537bf1d394401e61

commit b18b8c0d8c3014f76731eb80537bf1d394401e61
Author: Dave Andreoli 
Date:   Fri Jan 16 22:47:18 2015 +0100

Fix documentation for the Theme class
---
 efl/elementary/theme.pyx | 47 ---
 1 file changed, 20 insertions(+), 27 deletions(-)

diff --git a/efl/elementary/theme.pyx b/efl/elementary/theme.pyx
index 1754333..fb7b93d 100644
--- a/efl/elementary/theme.pyx
+++ b/efl/elementary/theme.pyx
@@ -147,8 +147,7 @@ cdef class Theme(object):
 """Return the default theme
 
 This returns the internal default theme setup handle that all widgets
-use implicitly unless a specific theme is set. This is also often use
-as a shorthand of NULL.
+use implicitly unless a specific theme is set.
 
 """
 cdef Theme ret = cls.__new__(cls)
@@ -170,11 +169,9 @@ cdef class Theme(object):
 """Copy the theme from the source to the destination theme
 
 This makes a one-time static copy of all the theme config, extensions
-and overlays from ``th`` to ``thdst``. If ``th`` references a theme, 
then
-``thdst`` is also set to reference it, with all the theme settings,
-overlays and extensions that ``th`` had.
+and overlays from this theme to ``dst``.
 
 :param Theme thdst: The destination theme to copy data to
 
 """
 elm_theme_copy(self.th, dst.th)
@@ -182,10 +179,10 @@ cdef class Theme(object):
 property reference:
 """Theme reference
 
-Setting this clears ``th`` to be empty and then sets it to refer to
-``thref`` so ``th`` acts as an override to ``thref``, but where its
-overrides don't apply, it will fall through to ``thref`` for
-configuration.
+Setting this clears the theme to be empty and then sets it to refer to
+another theme. This way the theme acts as an override to the reference,
+but where its overrides don't apply, it will fall through to
+reference for configuration.
 
 Getting it returns the theme that is referred to.
 
@@ -244,8 +241,7 @@ cdef class Theme(object):
 
 .. seealso:: :py:func:`overlay_add()`
 
-:param item: The name of the theme overlay
-:type item: string
+:param string item: The name of the theme overlay
 
 """
 if isinstance(item, unicode): item = PyUnicode_AsUTF8String(item)
@@ -322,9 +318,9 @@ cdef class Theme(object):
 """Set the theme search order for the given theme
 
 This sets the search string for the theme in path-notation from first
-theme to search, to last, delimited by the : character. Example:
+theme to search, to last, delimited by the ``:`` character. Example:
 
-"shiny:/path/to/file.edj:default"
+``shiny:/path/to/file.edj:default``
 
 See the ELM_THEME environment variable for more information.
 
@@ -355,8 +351,7 @@ cdef class Theme(object):
 This returns the internal list of theme elements (will only be valid as
 long as the theme is not modified by elm_theme_set() or theme is not
 freed by elm_theme_free(). This is a list of strings which must not be
-altered as they are also internal. If ``th`` is NULL, then the default
-theme element list is returned.
+altered as they are also internal.
 
 A theme element can consist of a full or relative path to a .edj file,
 or a name, without extension, for a theme to be searched in the known
@@ -376,10 +371,10 @@ cdef class Theme(object):
 def flush(self):
 """Flush the current theme.
 
-This flushes caches that let elementary know where to find theme 
elements
-in the given theme. If ``th`` is NULL, then the default theme is 
flushed.
-Call this function if source theme data has changed in such a way as to
-make any caches Elementary kept invalid.
+This flushes caches that let elementary know where to find theme
+elements in the given theme. Call this function if source theme data
+has changed in such a way as to make any caches Elementary kept
+invalid.
 
 """
 elm_theme_flush(self.th)
@@ -387,14 +382,13 @@ cdef class Theme(object):
 def data_get(self, key not None):
 """Get a data item from a theme
 
-This function is used to return data items from edc in ``th``, an
+This function is used to return data items from edc in theme, an
 overlay, or an extension. It works the same way as
-edje_file_data_get() except that the return is stringshared.
+:py:func:`efl.edje.Edje.data_get()`.
 
-:param key: The data key to search with
-:type key: string
+ 

[EGIT] [core/elementary] master 01/01: widget: elm_win can be unfocused only when its ecore_evas loses focus.

2015-01-16 Thread WooHyun Jung
woohyun pushed a commit to branch master.

http://git.enlightenment.org/core/elementary.git/commit/?id=cc0ea070b5e545f57832960c888d7591fafa1218

commit cc0ea070b5e545f57832960c888d7591fafa1218
Author: WooHyun Jung 
Date:   Sat Jan 17 16:29:46 2015 +0900

widget: elm_win can be unfocused only when its ecore_evas loses focus.
---
 src/lib/elm_widget.c | 34 --
 1 file changed, 32 insertions(+), 2 deletions(-)
@@ -170,11 +169,9 @@ cdef class Theme(object):
 
-:param Theme thdst: The destination theme to copy data to
+:param Theme dst: The destination theme to copy data to
 
 """
